From ab604fdb67296dad27f3a25f3c9aabdd2fb8c3fa Mon Sep 17 00:00:00 2001
From: Sergei Trofimovich <slyich@gmail.com>
Date: Thu, 11 Nov 2021 19:02:24 +0000
Subject: [PATCH] src/video.c: use %ld to print longs

ncurses-6.3 added printf()-stype attribute annotations for gcc-like
compilers that can now detect argument mismatches:

    video.c:114:26: error: format '%d' expects argument of type 'int',
      but argument 3 has type 'long unsigned int' [-Werror=format=]
      114 |                 printw(_("Viewing line %d/%d, 100%%"), lines, lines);
          |                          ^~~~~~~~~~~~~~~~~~~~~~~~~~~
---
 src/video.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/video.c b/src/video.c
index f6b444a..195d781 100644
--- a/src/video.c
+++ b/src/video.c
@@ -109,9 +109,9 @@ showscreen(char **message, unsigned long lines, unsigned long pos, long cursor,
 	mymvhline(maxy - 1, 0, ' ', maxx);
 	move(maxy - 1, 0);
 	if ((pos < lines - 1) &&(lines > pos + maxy - 2))
-		printw(_("Viewing line %d/%d, %d%%"), pos + maxy - 2, lines,((pos + maxy - 2) * 100) / lines);
+		printw(_("Viewing line %ld/%ld, %ld%%"), pos + maxy - 2, lines,((pos + maxy - 2) * 100) / lines);
 	else
-		printw(_("Viewing line %d/%d, 100%%"), lines, lines);
+		printw(_("Viewing line %ld/%ld, 100%%"), lines, lines);
 	info_add_highlights(pos, cursor, lines, column, message);
 	attrset(normal);
 	move(0, 0);
